/* launch the chk404.rxx daemon. To use this, you should modify
   the CUSTOM_INITS variable in SREFILTR.80.

   For example, the simplest way of invoking this "initialize
   the daemon procedure" is:

     CUSTOM_INITS='CHK_INIT '

   You can also set several parameters when launching CHK_INIT
   To do this, just enter the parameters immediately after the
   CHK_INIT.  

   The full syntax is:

     CUSTOM_INITS='CHK_INIT  port max404 duration keepout'

   Where:
          port == the http port you are using (default is 80).
        max404 == threshold number of 404 responses (default=8)
      duration == duration (in minutes) this threshold is computed over
                  (default=5)
      keepout  == duration (in minutes) to bar a client if a max404
                  violation occurs (default=15)
      verbose  == status message verbosity (1=some, 4=too much)
                  Default= value of the sref_verbose environment variable)
   Note that to specify a latter parameter (such as max404) you
   must also specify the port. If a parameters is unspecified,
   the default values (as noted below) will be used. 

   Basically,  if more then max404 "404" (resource not found) responses
               have been sent to an ip address in the last duration
               minutes, then this client is assumed to be an attacker.
               This condition will be assumed for the next keepout
               minutes; after which the slate is wiped clean (requests
               from the client will be treated as innocent).

    Examples:

  a) Use the default:
       CUSTOM_INITS='CHK_INIT '
 
  b) The port is 8080, and use the defaults
       CUSTOM_INITS='CHK_INIT 8080 '

  c) The port is the default (80), but set max404=10 and duration=20
     (and use the default value of keepout)
       CUSTOM_INITS='CHK_INIT 80 10 20 
    
*/

parse arg  stuff
parse var stuff aport max404 duration keepout verbose
if aport='' then aport=80
if max404='' then max404=8
if duration='' then duration=10
if keepout='' then keepout=15
IF VERBOSE=' ' then VERBOSE=1

if datatype(aport)<>'NUM' | datatype(max404)<>'NUM' | ,
   datatype(duration)<>'NUM' | datatype(keepout)<>'NUM' | ,
   DATATYPE(VERBOSE)<>'NUM' THEN DO
      call pmprintf(' CHK_INIT error -- bad parameter= 'aport ': 'max404 ': 'duration ': 'keepout' : ' VERBOSE)
   return 0
end /* do */

dmnname=strip('404CHECK_'||aport)

status=SREF_DMN_LAUNCH(dmnname,'chk404.rxx',aport' 'max404' 'duration' 'keepout' 'VERBOSE)
oo=sref_dmn_exist(dmnname)
if oo<>1 then do
   call pmprint(' 404CHECK Launch ERROR: daemon not launched 'oo)
   return 0
end /* do */
return 1


